@@ -1,10 +1,10 @@
-from rdap.common.constants import MessageColors
 import click
 
+
 @click.group(name="settings", invoke_without_command=True)
 @click.pass_context
 def settings(ctx):
-    """ Print the CLI settings. """
+    """Print the CLI settings."""
 
     if ctx.invoked_subcommand is None:
         print("SETTINGS WIP")
@@ -17,10 +17,11 @@ def set():
     """
     print("SET WIP")
 
+
 @settings.command()
 def show():
     """
     Show the available params of the CLI.
     Their status and values.
-    """    
-    print("SHOW WIP")
\ No newline at end of file
+    """
+    print("SHOW WIP")
